@@ -234,7 +234,7 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
 
 
-__version__ = '0.1.11'
+__version__ = '0.1.12'
 
 
 HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
@@ -372,9 +372,12 @@ class HelpAppBase(MainAppBase, ABC):
         :param event_kwargs:    optional args to pass additional data or info onto and from the event handler
                                 and to the help text renderer.
 
-                                info pass onto event handler:
+                                info pass onto event handler (e.g. from :attr:`~ae.kivy_app.FlowButton.tap_kwargs`
+                                or :attr:`~ae.kivy_app.FlowToggler.tap_kwargs`):
                                     * `popup_kwargs`: optional dict passed to the Popup `__init__` method,
                                       like e.g. dict(parent=parent_widget_of_popup, data=...).
+                                    * `tap_widget`: optional tapped button widget instance (initiating this
+                                      flow change).
 
                                 info passed from the event handler:
                                     * `flow_id`: process :attr:`~ae.gui_app.MainAppBase.flow_path` as specified by the
@@ -582,3 +585,9 @@ class HelpAppBase(MainAppBase, ABC):
             help_vars['self'] = wid
 
         return wid
+
+    def on_flow_popup_close(self, _flow_key: str, _popup_args: Dict[str, Any]) -> bool:
+        """ overwritten popup close handler of FlowPopup widget for to reset help widget/text. """
+        if self.help_layout:
+            self.help_display('', dict())
+        return True
